@@ -616,4 +616,26 @@ int yon_ip_check(char *ip);
 void yon_gtk_widget_register_parameter(GtkWidget *target, char *config_parameter, char *get_command, char *object_property);
 void yon_gtk_widget_register_parameter_manual(GtkWidget *target, char *config_parameter, char *get_command, char *object_property);
 void yon_gtk_widget_register_parameter_activate();
+
+typedef struct apps
+{
+    char *Name;
+    int Type;
+    char *Comment;
+    int categories_size;
+    config_str Categories;
+    char *Exec;
+    char *Icon;
+    int Pluggable;
+    int DualPluggable;
+} apps;
+
+void yon_apps_init();
+apps *yon_apps_get(char *name);
+config_str yon_apps_get_by_categories(config_str categories, int categories_size, int *final_size);
+
+
+/// @brief Block scroll element changing for GtkComboBox
+/// @param target - GtkComboBox to block
+void yon_gtk_combo_box_block_scroll(GtkComboBox *target);
 #endif
\ No newline at end of file
